Lua_TotemItemDetailsWindow = class("Lua_TotemItemDetailsWindow", Lua_Window)
function Lua_TotemItemDetailsWindow:ctor()
	self:superCall("ctor");
	
	self.layer = Lua_MainWinDefine.TIPS_WINDOW_LAYER;
	self.windowName = "Lua_TotemItemDetailsWindow";
	self.skinName = "TotemItemDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_TotemItemDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.attrItems = Array();

	self.scoreNum = Lua_NumberImage.new(self.showObject);
	self.scoreNum:setLocation(-67, -85.5, 0);
	self.scoreNum.pivot = 1;
	self.scoreNum.numOffsetX = -2;
	self.scoreNum.numAtlas = "number";
	self.scoreNum.preStr = "xui_zl1_number_0";

	self.btnStrengthen:setLangValue(309022);
	self.btnStrengthen:addClickFuntion(self, self.onStrengthenClick);
	self.btnSynthesis:addClickFuntion(self, self.onSynthesisClick);
	self.btnWear:addClickFuntion(self, self.onWearClick);
end

function Lua_TotemItemDetailsWindow:dispose()
	if self.attrItems then
		self.attrItems:dispose();
		self.attrItems:clear();
		self.attrItems = nil;
	end
	if self.scoreNum then
		self.scoreNum:dispose();
		self.scoreNum = nil;
	end
	if self.starList then
		self.starList:dispose();
		self.starList:clear();
		self.starList = nil;
	end
	if self.curSuit then
		self.curSuit:dispose();
		self.curSuit = nil;
	end
	if self.nextSuit then
		self.nextSuit:dispose();
		self.nextSuit = nil;
	end
	self.data = nil;
	self.lvCfg = nil;
	self:superCall("dispose");
	Lua_MsgUtil.callFunc("ITEM_DETAILS_CLOSE")
end

function Lua_TotemItemDetailsWindow:showWin(param)
	self:superCall("showWin", param);
	self.data = param.data;
	self.heroUid = DataCenter.totemData:getHeroUidByTotem(self.data.unique_id);

	local level = self.data.strengthenLv;
	self.lvCfg = DataCenter.totemUtil:getLevelConfig(self.data.id, level);
	if level > 0 then
		self.levelBg:setEnable(true);
		self.levelText:setEnable(true);
		self.levelText.text = LanUtil.formateStr(10049, tostring(level));
	else
		self.levelBg:setEnable(false);
		self.levelText:setEnable(false);
	end

	local width = 545;
	local height = 135;
	self.winBg:setAltas("common_altas_2", "xui_common_itembg_"..(self.data.color + 6));
	self.itemIcon:setAltas(self.data.atlas, self.data.sprite);
	self.itemIcon.name = self.data.id;
	self:showStar(self.data.star);

	local colorStr = Lua_ColorDefine.getItemColorStr(self.data.color, true);
	self.nameText.colorStr = Lua_ColorDefine.transColorStr(colorStr);
	self.nameText.text = self.data.name;
	self.posText.text = LanUtil.formateStr(762000, convert_arab_to_chinese(self.data.part));
	self.scoreNum.num = self.data.score;

	self.mainTitle:setEnable(true);
	local addH = 40;
	local startY = -139.5;

	local len = self.attrItems:getSize();
	for i = 1, len do
		self.attrItems[i]:setEnable(false);
	end
	local index = 1;
	local item;

	local attrArr = DataCenter.totemData:getMainAttrArr(self.data);
	len = attrArr:getSize();
	for i = 1, len do
		item = self:createAttrItem(index);
		item:setLocation(-250, startY - addH - (i - 1) * 40, 0);
		if attrArr[i].nextValue > 0 then
			str = LanUtil.formateStr(762025, attrArr[i].show_name, attrArr[i].showValue, attrArr[i].showNextValue);
		else
			str = LanUtil.formateStr(762024, attrArr[i].show_name, attrArr[i].showValue);
		end
		item:setData("common_altas_2", attrArr[i].attr_icon_2, str);

		index = index + 1;
	end
	addH = addH + len * 40;

	self.randomTitle:setEnable(true);
	self.randomTitle:setLocation(-250, startY - addH, 0);
	addH = addH + 40;

	attrArr = DataCenter.totemData:getRandomAttrArr(self.data);
	if attrArr == nil then
		item = self:createAttrItem(index);
		item:setLocation(-250, startY - addH, 0);
		item:setData(nil, nil, DataCenter.totemUtil:getRandomAttrLangId(self.data.star));
		index = index + 1;
		addH = addH + 40;
	else
		len = attrArr:getSize();
		for i = 1, len do
			item = self:createAttrItem(index);
			item:setLocation(-250, startY - addH - (i - 1) * 40, 0);
			if attrArr[i].nextValue > 0 then
				str = LanUtil.formateStr(762025, attrArr[i].show_name, attrArr[i].showValue, attrArr[i].showNextValue);
			else
				str = LanUtil.formateStr(762024, attrArr[i].show_name, attrArr[i].showValue);
			end
			item:setData("common_altas_2", attrArr[i].attr_icon_2, str);
			index = index + 1;
		end
		addH = addH + len * 40;
	end

	self.suitTitle:setEnable(true);
	self.suitTitle:setLocation(-250, startY - addH, 0);
	addH = addH + 40;

	local state = false;
	local suitCfg = DataCenter.totemUtil:getSuitConfig(self.data.suitId);
	local suitNum = nil;
	if self.heroUid > 0 then
		local info = DataCenter.totemData:getHeroTotemInfo(self.heroUid);
		if info and info.suit_list then
			local _suitCfg;
			for i = 1, #info.suit_list do
				_suitCfg = DataCenter.totemUtil:getSuitConfig(info.suit_list[i]);
				if _suitCfg.totem_type == suitCfg.totem_type then
					state = true;
					suitCfg = _suitCfg;
					break;
				end
			end
		end
		suitNum = DataCenter.totemData:getHeroWearNum(self.heroUid, suitCfg);
	end
	if self.curSuit == nil then
		self.curSuit = Lua_TotemItemSuitItem.new(self.showObject);
		self.curSuit:setLocation(0, startY - addH, 0);
	end
	addH = addH + self.curSuit:setData(state, suitCfg, suitNum) + 20;
	if state and suitCfg.next_suit_id and suitCfg.next_suit_id > 0 then
		addH = addH + 10; -- 间隔
		if self.nextSuit == nil then
			self.nextSuit = Lua_TotemItemSuitItem.new(self.showObject);
		end
		self.nextSuit:setEnable(true);
		self.nextSuit:setLocation(0, startY - addH, 0);

		suitCfg = DataCenter.totemUtil:getSuitConfig(suitCfg.next_suit_id);
		local num = DataCenter.totemData:getHeroWearNum(self.heroUid, suitCfg);
		addH = addH + self.nextSuit:setData(false, suitCfg, num) + 20;
	else
		if self.nextSuit then
			self.nextSuit:setEnable(false);
		end
	end

	if param.isShowBtns then
		self.btnObject:SetActive(true);
		if self.heroUid == 0 then
			self.btnSynthesis:setLangValue(309012);
			self.btnWear:setLangValue(309016);
		else
			self.btnSynthesis:setLangValue(309020);
			self.btnWear:setLangValue(309021);
		end
		LuaUtil.setObjPos(self.btnObject, 0, startY - addH, 0);
		addH = addH + 110;
	else
		self.btnObject:SetActive(false);
	end

	height = height + addH;
	self.winBg:SetDimensions(width, height);
	LuaUtil.setObjPos(self.showObject, 0, height / 2, 0);
end

function Lua_TotemItemDetailsWindow:createAttrItem(index)
	local item = self.attrItems[index];
	if item == nil then
		item = Lua_AttrIconItem.new(self.showObject);
		item.pivot = 1;
		item.spacingX = 10;
		self.attrItems:add(item);
	else
		item:setEnable(true);
	end
	return item;
end

function Lua_TotemItemDetailsWindow:showStar(num)
	if self.starList == nil then
		self.starList = Array();
	end
	num = num or 0;
	local len = self.starList:getSize();
	local maxLen = num > len and num or len;
	local icon;
	for i = 1, maxLen do
		icon = self.starList[i];
		if i > num then
			if icon then
				icon:setEnable(false);
			end
		else
			if icon == nil then
				icon = UICreate.createUIAtlasImage(self.showObject, "common_altas_1", "xui_common_label_09", 0, 0, 0, 0);
				self.starList:add(icon);
			else
				icon:setEnable(true);
			end
		end
	end
	if num > 0 then
		local space = 10
		local w = -(space * num) / 2 + space / 2
		for i = 1, num do
			icon = self.starList[i]
			icon:setLocation(-195 + ((i - 1) % num) * space + w, -94, 0)
		end
	end
end

function Lua_TotemItemDetailsWindow:onStrengthenClick(go)
	Lua_WindowUtil.openWin("Lua_TotemStrengthenWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_TotemItemDetailsWindow:onSynthesisClick(go)
	if self.heroUid == 0 then
		Lua_WindowUtil.openWin("Lua_TotemSynthesisWindow", Lua_WinParam.ACTION_OPEN);
	else
		Lua_WindowUtil.openWin("Lua_TotemReplaceWindow", Lua_WinParam.ACTION_OPEN, { data = self.data, heroUid = self.showData.heroUid });
	end
end

function Lua_TotemItemDetailsWindow:onWearClick(go)
	if self.heroUid == 0 then
		DataCenter.funcPathUtil:gotoFunction(1033, true);
	else
		local arr = Array();
		arr:add(self.data.unique_id);
		Lua_ProxyManager.getProxy("Lua_TotemProxy"):sRemove(self.heroUid, arr);
	end
end










Lua_TotemItemSuitItem = class("Lua_TotemItemSuitItem", Lua_DisplayObject)
function Lua_TotemItemSuitItem:ctor(p)
	self:superCall("ctor", p, "TotemItemSuitItem_skin");
end

function Lua_TotemItemSuitItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_TotemItemSuitItem:dispose()
	self:superCall("dispose");
end

function Lua_TotemItemSuitItem:setData(state, data, suitNum)
	if state then
		self.titleText.colorStr = Lua_ColorDefine.transColorStr("BBBBBB");
		self.levelText.colorStr = Lua_ColorDefine.transColorStr("BBBBBB");
		self.desText.colorStr = Lua_ColorDefine.transColorStr("BBBBBB");
	else
		self.titleText.colorStr = Lua_ColorDefine.transColorStr("85868B");
		self.levelText.colorStr = Lua_ColorDefine.transColorStr("85868B");
		self.desText.colorStr = Lua_ColorDefine.transColorStr("85868B");
	end

	if suitNum == nil then
		self.titleText.text = data.title;
	else
		suitNum = suitNum > data.need_amount and data.need_amount or suitNum;
		self.titleText.text = data.title..LanUtil.formateStr(10061, tostring(suitNum), tostring(data.need_amount));
	end
	self.levelText.text = LanUtil.formateStr(10041, tostring(data.level));
	self.desText.text = data.des;
	self.desText:resetSize();
	return Mathf.Abs(self.desText.posY) + self.desText.height;
end